const toggleSsrRelatedConfig = ({ configDefinedAt, configValue }) => {
    if (typeof configValue !== 'boolean') {
        throw new Error(`${configDefinedAt} should be a boolean`);
    }
    return {
        meta: {
            // When the SSR flag is false, we want to render the page only in the
            // browser. We achieve this by then making the `Page` implementation
            // accessible only in the client's renderer.
            Page: {
                env: configValue
                    ? { server: true, client: true } // default
                    : { client: true }
            }
        }
    };
};
export default {
    onRenderHtml: 'import:vike-builders/renderer/onRenderHtml:onRenderHtml',
    onRenderClient: 'import:vike-builders/renderer/onRenderClient:onRenderClient',
    passToClient: ['pageProps', 'title'],
    clientRouting: false,
    hydrationCanBeAborted: true,
    meta: {
        Head: {
            env: { server: true }
        },
        Layout: {
            env: { server: true, client: true }
        },
        title: {
            env: { server: true, client: true }
        },
        description: {
            env: { server: true }
        },
        theme: {
            env: { server: true, client: true }
        },
        favicon: {
            env: { server: true }
        },
        lang: {
            env: { server: true }
        },
        ssr: {
            env: { config: true },
            effect: toggleSsrRelatedConfig
        },
        stream: {
            env: { server: true }
        },
        VikeReactQueryWrapper: {
            env: { client: true, server: true }
        }
    }
};
